@@ -4,6 +4,7 @@ import pkg_resources
 from django.apps import AppConfig
 
 import gdaps
+from gdaps.api import PluginConfig
 from gdaps.apps import GdapsConfig
 from gdaps.frontend.api import current_engine
 
@@ -18,7 +19,7 @@ class FrontendPluginMeta:
     category = GdapsConfig.PluginMeta.category
 
 
-class FrontendConfig(AppConfig):
+class FrontendConfig(PluginConfig):
     name = "gdaps.frontend"
     label = "gdaps_frontend"
     verbose_name = "GDAPS frontend"
@@ -33,7 +34,6 @@ class FrontendConfig(AppConfig):
             entry_point.load()
             entry_points.append(entry_point.name)
 
-
             # if there is an engine selected in settings, check if everything it needs is available
             if current_engine():
                 current_engine().check_runtime_prereq()
