@@ -33,12 +33,13 @@ class Command(TemplateCommand):
 
         self.rewrite_template_suffixes = current_engine().rewrite_template_suffixes
 
+        current_engine().check_install_prereq()
+
         self.create_directory(self.target_path)
 
         # run initialisation of engine
         current_engine().initialize(frontend_dir)
 
-        project_title = gdaps_settings.PROJECT_TITLE or settings.PROJECT_NAME.replace("_", " ").capitalize()
         project_version = "0.0.1"
 
         self.context = Context(
@@ -46,7 +47,7 @@ class Command(TemplateCommand):
                 **options,
                 "project_name": settings.PROJECT_NAME,
                 "project_version": project_version,
-                "project_title": project_title,
+                "project_title": gdaps_settings.PROJECT_TITLE,
                 "frontend_dir": frontend_dir,
                 "frontend_path": self.target_path,
                 "docs_version": get_docs_version(),
